---
title: "Ebola"
template: 'post.html'
published: true
comments: false
tags: [leaflet, mapbox, backbone, underscore]
scripts: []
styles: []
excerpt: "Watch Ebola spread across West Africa and beyond"
---

I've been working with [Frontline](http://frontline.pbs.org) lately. Here's a recent project:

<iframe src="http://apps.frontline.org/ebola/" width="100%" frameborder="0" height="510px"></iframe>

The map is [Leaflet][ll] using [Mapbox.js][mb]. Everything is wrapped in [Backbone][bb]. Outbreak data comes from WHO, CDC, New England Journal of Medicine and Science.

 [ll]: http://leafletjs.com
 [mb]: https://www.mapbox.com/mapbox.js/
 [bb]: http://backbonejs.org/